==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/sms/translations/sms_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation>SMS Nickname</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Programma</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Usa l&apos;applicazione SMS incorporata</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Applicazione SMS esterna</translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation>Usa stringa personalizzata SMS</translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation>Stringa personalizzata SMS</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Manda SMS</translation>
    </message>
    <message>
        <source>SMS T-Mobile.pl Gateway</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS proxy for built-in application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation type="unfinished">Manda SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Signature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> - Select recipient - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Detecting gateway...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Detected gateway: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsTokenReadJob</name>
    <message>
        <source>Invalid paremeters for token read job.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading token image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to fetch token image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read token image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting for entry of token value...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No token value provided.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Received token value.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/sms/translations/sms_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Programma</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Usa l&apos;applicazione SMS incorporata</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Applicazione SMS esterna</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Manda SMS</translation>
    </message>
    <message>
        <source>SMS T-Mobile.pl Gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sponsored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SMS proxy for built-in application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extras</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your nick for SMS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use application custom arguments</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SMS custom arguments</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Conservazione</translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation>Manda SMS...</translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation>Manda SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>GSM provider</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Signature</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> - Select recipient - </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SMS sent</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Signature can&apos;t be empty.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Detecting gateway...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Detected gateway: %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SMS sent</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SmsTokenReadJob</name>
    <message>
        <source>Invalid paremeters for token read job.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading token image...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to fetch token image.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to read token image.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Waiting for entry of token value...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No token value provided.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Received token value.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
